@@ -152,9 +152,12 @@ extern "C" {
   static void samplerFinalizer(SEXP samplerExpr);
   static void storedBARTSamplerFinalizer(SEXP samplerExpr);
   
-#if defined(__clang__) && __clang_major__ >= 10
-#  pragma clang diagnostic push
-#  pragma clang diagnostic ignored "-Wenum-enum-conversion"
+#ifdef __clang__
+#  if __has_warning("-Wenum-enum-conversion")
+#    define SUPPRESS_ENUM_CONVERSION_WARNING 1
+#    pragma clang diagnostic push
+#    pragma clang diagnostic ignored "-Wenum-enum-conversion"
+#  endif
 #endif
   
   static SEXP createSampler(SEXP bartControlExpr, SEXP bartDataExpr, SEXP bartModelExpr,
@@ -278,7 +281,7 @@ extern "C" {
     return result;
   }
   
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic pop
 #endif
   
@@ -315,7 +318,7 @@ extern "C" {
     return result;
   }
   
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic push
 #  pragma clang diagnostic ignored "-Wenum-enum-conversion"
 #endif
@@ -371,7 +374,7 @@ extern "C" {
     return result;
   }
   
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic pop
 #endif
   
@@ -414,7 +417,7 @@ extern "C" {
     return result;
   }
   
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic push
 #  pragma clang diagnostic ignored "-Wenum-enum-conversion"
 #endif
@@ -589,7 +592,7 @@ extern "C" {
     return(resultExpr);
   }
   
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic pop
 #endif
   
@@ -630,7 +633,7 @@ extern "C" {
 
 namespace {
 
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic push
 #  pragma clang diagnostic ignored "-Wenum-enum-conversion"
 #endif
@@ -664,8 +667,9 @@ void initializeSamplerFromExpression(Sampler& sampler, SEXP commonControlExpr)
     sampler.refresh = 200;
 }
 
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic pop
+#  undef SUPPRESS_ENUM_CONVERSION_WARNING
 #endif
 
 }
@@ -842,3 +846,4 @@ void attribute_visible R_init_stan4bart(DllInfo *info) {
 }
 
 } // extern "C"
+
