@@ -91,9 +91,12 @@ std::ostream nullout(nullptr);
 
 namespace stan4bart {
 
-#if defined(__clang__) && __clang_major__ >= 10
-#  pragma clang diagnostic push
-#  pragma clang diagnostic ignored "-Wenum-enum-conversion"
+#ifdef __clang__
+#  if __has_warning("-Wenum-enum-conversion")
+#    define SUPPRESS_ENUM_CONVERSION_WARNING 1
+#    pragma clang diagnostic push
+#    pragma clang diagnostic ignored "-Wenum-enum-conversion"
+#  endif
 #endif
 
 StanModel* createStanModelFromExpression(SEXP dataExpr)
@@ -366,7 +369,7 @@ StanModel* createStanModelFromExpression(SEXP dataExpr)
   return result;
 }
 
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic pop
 #endif
 
@@ -374,7 +377,7 @@ void deleteStanModel(StanModel* model) {
   delete model;
 }
 
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic push
 #  pragma clang diagnostic ignored "-Wenum-enum-conversion"
 #endif
@@ -444,7 +447,7 @@ void initializeStanControlFromExpression(StanControl& control, SEXP controlExpr)
   misc_stackFree(matchPos);
 }
 
-#if defined(__clang__) && __clang_major__ >= 10
+#ifdef SUPPRESS_ENUM_CONVERSION_WARNING
 #  pragma clang diagnostic pop
 #endif
 
